clear all
version 12
set more off

/************ generate cyclical variables from personal income *********/
tempfile cyclical_vars

use bds_2groups_sector, clear

* output data for each of the our major industry categories
levelsof sicg, local(industries)
foreach ind of local industries {
	use bds_2groups_sector, clear
	
	* bring in cyclical indicators
	merge m:1 year2 using cyclical_indicators
	* keep only selected industry
	keep if sicg==`ind'
	egen empyr = sum(emp), by(year2 ageg) /* weight equally across years within age groups*/
	gen wgt = emp/empyr
	keep if year2 >= 1980
	
	/** filter startup growth **/
	preserve
	keep if ageg == 1
	/* linear trend */
	reg njcr year2
	predict gs_t_res if ageg == 1, resid
	predict gs_t_res_s if ageg == 1
	keep year2 ageg gs_t_*
	tempfile filtered_data
	save `filtered_data', replace
	restore
	
	merge 1:1 year2 ageg using `filtered_data', nogen
	
	/** estimate betas by age group */
	* young
	reg njcr c.pi_method1 [aw=wgt] if ageg == 2, cluster(year)
	gen beta = _b[pi_method1] if ageg == 2
	* mature 
	reg njcr c.pi_method1 [aw=wgt] if ageg == 3, cluster(year)
	replace beta = _b[pi_method1] if ageg == 3
	* startups
	reg gs_t_res pi_method1 [aw=wgt] if ageg == 1, cluster(year)
	replace beta = _b[pi_method1] if ageg==1 
	* collapse and remerge
	collapse (mean) beta, by(year2 ageg)

	/** step 2: define national cyclical variables **/
	merge 1:m year2 ageg using bds_2groups_sector, nogen keep(match master)
	merge m:1 year2 using cyclical_indicators, nogen 
	replace njcr = njcr - 1 if ageg == 1 /* njcr defined as 1 + gs_t */
	keep if sicg==`ind'
	
	* trend component: startups
	preserve
	tempfile startup_trend
	keep if ageg == 1
	tsset year2
	tsfilter hp gs_t_hp_100 = njcr if year2 >= 1980, s(6) trend(trend)
	save `startup_trend', replace
	restore
	merge 1:1 year2 ageg using `startup_trend', keepusing(trend) nogenerate

	* trend component: incumbents
	tempvar xtrend
	egen `xtrend' = mean(njcr), by(ageg)
	replace trend = `xtrend' if ageg != 1
	
	* cyclical component for y/m by multiplying by de-meaned shock
	reg pi_method1 if year2 >= 1987
	predict shock, resid
	gen double cyc = shock*beta 
	
	* generate residual for matlab
	gen double resid = njcr - trend - cyc 

	save `cyclical_vars', replace
	/************************************************************************/

	/* now remerge cyclical variables for outputting to Matlab */
	use bds_2groups_sector
	keep if sicg==`ind'
	merge 1:1 year2 ageg using `cyclical_vars'
	keep if ageg < .

	keep year2 ageg emp emptot emplag1tot empshr emplag1shr njcr njcrtot firmsurv avgsize avgsizegrowth trend beta shock cyc resid
	reshape wide emp empshr emplag1shr njcr njcrtot firmsurv avgsize avgsizegrowth trend beta shock cyc resid, i(year2) j(ageg)

	gen long emp_s = emp1
	gen long emp_y = emp2
	gen long emp_m = emp3

	gen long emp_t = emptot
	gen long emp_tm1 = emplag1tot

	gen double empshr_s = empshr1
	gen double empshr_y = empshr2
	gen double empshr_m = empshr3

	gen double njcr_s = njcr1
	gen double njcr_y = njcr2
	gen double njcr_m = njcr3

	gen double njcrtot = njcrtot1

	gen double firmsurv_y = firmsurv2
	gen double firmsurv_m = firmsurv3

	gen double avgsize_s = avgsize1
	gen double avgsize_y = avgsize2
	gen double avgsize_m = avgsize3

	gen double avgsizegrowth_y = avgsizegrowth2
	gen double avgsizegrowth_m = avgsizegrowth3

	gen double emplag1shr_s = emplag1shr1
	gen double emplag1shr_y = emplag1shr2
	gen double emplag1shr_m = emplag1shr3

	gen double mu = trend1
	gen double gbar_y = trend2
	gen double gbar_m = trend3

	gen gc_s = cyc1
	gen gc_y = cyc2
	gen gc_m = cyc3

	gen double resid_s = resid1
	gen double resid_y = resid2 
	gen double resid_m = resid3

	gen beta_s = beta1
	gen beta_y = beta2
	gen beta_m = beta3

	gen shock = shock1
	
	
	/* generate average shares for 1980-84 for counterfactuals in matlab */
	preserve
	tempfile sector_shr1
	use bds_sector.dta, clear
	keep emp sicg year2
	bys year2: egen emp_tot=total(emp)
	gen sector_shr=emp/emp_tot
	save `sector_shr1', replace
	
	tempfile sector_shr
	use bds_2groups_sector.dta, clear
	keep emp sicg ageg year2
	drop if ageg==.
	bys year2 ageg: egen emp_age=total(emp)
	bys year2 (ageg): gen emp_tot_s=emp_age[1]
	bys year2 sicg (ageg): gen emp_s=emp[1]
	collapse (mean) emp_tot_s emp_s, by(sicg year2)
	gen sector_shr_s=emp_s/emp_tot_s
	merge 1:1 year2 sicg using `sector_shr1', keep(3) nogen keepus(sector_shr)
	
	bys sicg (year): gen sec_shr_avg=(sector_shr[_n]+sector_shr[_n-1]+sector_shr[_n-2]+sector_shr[_n-3]+sector_shr[_n-4])/5
	bys sicg (year): gen sec_shr_s_avg=(sector_shr_s[_n]+sector_shr_s[_n-1]+sector_shr_s[_n-2]+sector_shr_s[_n-3]+sector_shr_s[_n-4])/5
	keep if year>=1984
	bys sicg (year): gen sec_shr_avg8084=sec_shr_avg[1]
	bys sicg (year): gen sec_shr_s_avg8084=sec_shr_s_avg[1]
	gen s_bar_secshr=sec_shr_avg8084*emp_tot_s
	gen s_bar_secshr_s=sec_shr_s_avg8084*emp_tot_s
	keep if sicg==`ind'
	keep s_bar_secshr s_bar_secshr_s year2
	save `sector_shr', replace
	restore
	

	preserve
	sort year2
	gen emp_s_avg=(emp_s[_n]+emp_s[_n-1]+emp_s[_n-2]+emp_s[_n-3]+emp_s[_n-4])/5
	keep if year2>=1984
	gen s_bar8084=emp_s_avg[1]
	drop emp_s_avg
	keep if year2 >= 1987 & year2<=2013
	merge 1:1 year2 using `sector_shr', keep(3) nogen
	keep year2 emp_* empshr_* njcr_* njcrtot firmsurv_* avgsize_* ///
	  avgsizegrowth_* emplag1shr_* gc_* mu gbar_* resid_* beta_* shock ///
	  s_bar8084 s_bar_secshr s_bar_secshr_s
	  
	order year2 emp_* empshr_* njcr_* njcrtot firmsurv_* avgsize_* ///
	  avgsizegrowth_* emplag1shr_* gc_* mu gbar_* resid_* beta_* shock ///
	  s_bar8084 s_bar_secshr s_bar_secshr_s
	foreach var of varlist * {
		replace `var'=0 if `var'==.
	}
	descr
	outsheet using sector_model/bds_2group_wide_sic`ind'_appendix.txt, replace
	restore
	
	preserve
	keep if year >= 1980 & year<=2013
	keep year2 emp_s empshr_s emp_t emp_tm1 njcr_s njcrtot avgsize_s emplag1shr_s gc_s mu resid_s beta_s shock
	descr
	outsheet using sector_model/bds_startupshare_wide_sic`ind'_appendix.txt, replace
	restore
}

